# coding: utf-8

"""
    Hatchet API

    The Hatchet API

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from datetime import datetime
from typing import Any, ClassVar, Dict, List, Optional, Set

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing_extensions import Self


class RateLimit(BaseModel):
    """
    RateLimit
    """  # noqa: E501

    key: StrictStr = Field(description="The key for the rate limit.")
    tenant_id: StrictStr = Field(
        description="The ID of the tenant associated with this rate limit.",
        alias="tenantId",
    )
    limit_value: StrictInt = Field(
        description="The maximum number of requests allowed within the window.",
        alias="limitValue",
    )
    value: StrictInt = Field(
        description="The current number of requests made within the window."
    )
    window: StrictStr = Field(
        description="The window of time in which the limitValue is enforced."
    )
    last_refill: datetime = Field(
        description="The last time the rate limit was refilled.", alias="lastRefill"
    )
    __properties: ClassVar[List[str]] = [
        "key",
        "tenantId",
        "limitValue",
        "value",
        "window",
        "lastRefill",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of RateLimit from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of RateLimit from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "key": obj.get("key"),
                "tenantId": obj.get("tenantId"),
                "limitValue": obj.get("limitValue"),
                "value": obj.get("value"),
                "window": obj.get("window"),
                "lastRefill": obj.get("lastRefill"),
            }
        )
        return _obj
